
#------------------------------------------------------------------------------
#
# 1. DISCLAIMER
#    THE SOFTWARE AND/OR RELATED MATERIALS ARE PROVIDED "AS-IS" WITHOUT
#    WARRANTY OF ANY KIND INCLUDING ANY WARRANTIES OF PERFORMANCE OR
#    MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE OR PURPOSE (AS SET FORTH
#    IN UCC 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE LICENSED
#    PRODUCT, HOWEVER USED.
#
#    IN NO EVENT SHALL CALTECH/JPL BE LIABLE FOR ANY DAMAGES AND/OR COSTS,
#    INCLUDING BUT NOT LIMITED TO INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY
#    KIND, INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
#    REGARDLESS OF WHETHER CIT/JPL SHALL BE ADVISED, HAVE REASON TO KNOW,
#    OR IN FACT SHALL KNOW OF THE POSSIBILITY.
#
#    USER BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF THE SOFTWARE
#    AND/OR RELATED MATERIALS.
#
# 2. The user shall comply with all applicable U.S. export control laws and
#    regulations.  To the extent that the software is subject to U.S. export
#    control laws and regulations, the user has the responsibility to obtain
#    export licenses or other export authority as may be required before
#    exporting such information to foreign countries or providing access to
#    foreign persons.
#
#------------------------------------------------------------------------------

#========================================================================
# File Name: airs_env.py
# Directory: /home/rickf/Direct_Broadcast/bin/python/new_dev/Recovery
#
# Description:  airs_env.py provides a series of subroutines for the
# manipulation of environment variables and related values.
#
# Developed as a component part of the AIRS Direct Broadcast system.
#========================================================================

import os, string, airs_utils

ENV = {'ARCH'			:'UNKNOWN',
       'DEM_DATA'		:'/opt/DEM',
       'PGSHOME'		:'UNKNOWN',
       'HDFSYS'			:'UNKNOWN',
       'PGSBIN'			:'UNKNOWN',
       'PGSDAT'			:'UNKNOWN',
       'PGSINC'			:'UNKNOWN',
       'PGSLIB'			:'UNKNOWN',
       'PGSMSG'			:'UNKNOWN',
       'PGSOBJ'			:'UNKNOWN',
       'PGSRUN'			:'UNKNOWN',
       'PGSSRC'			:'UNKNOWN',
       'PGSTST'			:'UNKNOWN',
       'PGS_PC_INFO_FILE'	:'UNKNOWN',
       'HDFHOME'		:'UNKNOWN',
       'HDFBIN'			:'UNKNOWN',
       'HDFINC'			:'UNKNOWN',
       'HDFLIB'			:'UNKNOWN',
       'HDFEOS_HOME'		:'UNKNOWN',
       'HDFEOS_INC'		:'UNKNOWN',
       'HDFEOS_BIN'		:'UNKNOWN',
       'AIRSROOT'		:'UNKNOWN',
       'AIRSHOME'		:'UNKNOWN',
       'AIRS_ARCH'		:'UNKNOWN',
       'AIRS_TLSCF'		:'UNKNOWN',
       'AIRSDB'			:'UNKNOWN',
       'AIRSDB_HOME'		:'UNKNOWN',
       'AIRSDB_BIN'		:'UNKNOWN',
       'AIRSDB_RUN'		:'UNKNOWN',
       'AIRSDB_PACKETS'		:'UNKNOWN',
       'AIRSDB_EXE'		:'UNKNOWN',
       'AIRSDB_DYNAMIC'		:'UNKNOWN',
       'AIRSDB_PCFTMPLTE'	:'UNKNOWN',
       'AIRSDB_DATAIN'		:'UNKNOWN',
       'AIRSDB_LOGS'		:'UNKNOWN',
       'WORKING_DIR'		:'UNKNOWN',
       'ANC_STATIC'		:'UNKNOWN',
       'ANC_DYNAMIC'		:'UNKNOWN',
       'MCF_DIR'		:'UNKNOWN',
       'PCF_DIR'		:'UNKNOWN'
       }
DEPS = {'PGSBIN'		: '<PGSHOME>/bin/<ARCH_TOOLKIT>',
        'PGSDAT'		: '<PGSHOME>/database/<ARCH_TOOLKIT>',
        'PGSINC'		: '<PGSHOME>/include',
        'PGSLIB'		: '<PGSHOME>/lib/<ARCH_TOOLKIT>',
        'PGSMSG'		: '<AIRSROOT>/<ARCH>/message',
        'PGSOBJ'		: '<PGSHOME>/obj/<ARCH_TOOLKIT>',
        'PGSRUN'		: '<PGSHOME>/runtime',
        'PGSSRC'		: '<PGSHOME>/src',
        'PGSTST'		: '<PGSHOME>/test',
        'HDFBIN'		: '<HDFHOME>/bin',
        'HDFINC'		: '<HDFHOME>/include',
        'HDFLIB'		: '<HDFHOME>/lib',
        'HDFEOS_INC'		: '<HDFEOS_HOME>/include',
        'HDFEOS_BIN'		: '<HDFEOS_HOME>/bin',
	'HDFEOS_LIB'		: '<HDFEOS_HOME>/lib/<ARCH_TOOLKIT>',
        'AIRSHOME'		: '<AIRSROOT>',
        'AIRS_ARCH'		: '<AIRSROOT>/<ARCH>',
        'AIRS_TLSCF'		: 'DB',
        'AIRSDB_HOME'		: '<AIRSDB>',
        'AIRSDB_BIN'		: '<AIRSDB>/bin',
        'AIRSDB_RUN'		: os.environ['PWD'],
        'AIRSDB_EXE'		: '<AIRSDB>/bin',
        'AIRSDB_PCFTMPLTE'	: '<AIRSROOT>/STORE/pcf',
        'AIRSDB_LOGS'		: '<AIRSROOT>/<ARCH>/message',
       }

Add2Path=['<AIRSROOT>/DEVELOPMENT/scripts',
	  '<AIRSDB>/bin']


IndexTbl = {}

DEFAULTS = {'ARCH'		:'SUN',
            'DEM_DATA'		:'/opt/DEM',
            }

def getENV(envvar):
   if (ENV.has_key(envvar)):
      return ENV[envvar]
   else:
      return 'UNKNOWN'

def setENV(envvar, envval, intval=0):
   if (envval != ''):
      ENV[envvar] = envval
   else:
      ENV[envvar] = intval
   if (os.environ.has_key(envvar)):
      os.environ[envvar] = envval

def initENVTbl():
   if (os.environ.has_key('ARCH_TOOLKIT')):
       arch_toolkit_val = os.environ['ARCH_TOOLKIT']
   elif (os.environ.has_key('ARCH')):
       arch_toolkit_val = os.environ['ARCH']

   for idx in range (len(Add2Path)):
      Add2Path[idx] = string.replace(Add2Path[idx], '<AIRSROOT>', os.environ['AIRSROOT'])
      Add2Path[idx] = string.replace(Add2Path[idx], '<AIRSDB>', os.environ['AIRSDB'])
   for KEY in DEPS.keys():
      DEPS[KEY] = string.replace(DEPS[KEY], '<AIRSROOT>', os.environ['AIRSROOT'])
      DEPS[KEY] = string.replace(DEPS[KEY], '<PGSHOME>', os.environ['PGSHOME'])
      DEPS[KEY] = string.replace(DEPS[KEY], '<AIRSDB>', os.environ['AIRSDB'])
      DEPS[KEY] = string.replace(DEPS[KEY], '<HDFHOME>', os.environ['HDFHOME'])
      DEPS[KEY] = string.replace(DEPS[KEY], '<HDFEOS_HOME>', os.environ['HDFEOS_HOME'])
      DEPS[KEY] = string.replace(DEPS[KEY], '<ARCH_TOOLKIT>', arch_toolkit_val)
      DEPS[KEY] = string.replace(DEPS[KEY], '<ARCH>', os.environ['ARCH'])
      os.environ[KEY] = DEPS[KEY]

   for KEY in ENV.keys():
      if os.environ.has_key(KEY):
         ENV[KEY] = os.environ[KEY]
      else:
         ENV[KEY] = 'UNKNOWN'
   for KEY in DEPS.keys():
      ENV[KEY] = DEPS[KEY]
   for KEY in DEFAULTS.keys():
      if (ENV[KEY] == 'UNKNOWN'):
         ENV[KEY] = DEFAULTS[KEY]
      

def validateENV():
   for KEY in ENV.keys():
      if (ENV[KEY] == 'UNKNOWN'):
         return 0
   return 1

# The IndexTbl allows simple access to points in the PCF file where a value
# in the ENVTbl need to be placed, but the pcf file does not provide a 
# "place holder" such as the "must-set-anc-directory" and similar.  These
# must be handled as field replacements, not string replacements.
def initIndexTbl():
   IndexTbl['STARTTIME-AIRS'] = [['10258',2]]
   IndexTbl['STARTTIME-AMSU'] = [['10258',2]]
   IndexTbl['STARTTIME-HSB'] = [['10258',2]]
   IndexTbl['ENDTIME-AIRS'] = [['10259',2]]
   IndexTbl['ENDTIME-AMSU'] = [['10259',2]]
   IndexTbl['ENDTIME-HSB'] = [['10259',2]]
   IndexTbl['FIRST_GRANULE'] = [['1015',2]]
   IndexTbl['GRANULE_COUNT'] = [['1022',2]]
   IndexTbl['GRANULE_SIZE'] = [['1016',2]]
   IndexTbl['DEM_DATA'] = [['10650',2],['10651',2],['10656',2]]
   IndexTbl['INSTRUMENT'] = [['1001',2]]
   IndexTbl['LOGSTATUS'] =[['10100',1]]
   IndexTbl['LOGREPORT'] =[['10101',1]]
   IndexTbl['LOGUSER'] =[['10102',1]]
   IndexTbl['SHMMEM'] =[['10111',1]]
   IndexTbl['WORKING_DIR'] =[['10100',2],['10101',2],['10102',2],['10111',2]]

def setIndex(envvar, LID, Fld):
   if (IndexTbl.has_key(envvar)):
      IndexTbl[envvar].append([LID, Fld])
   else:
      IndexTbl[envvar] = []
      IndexTbl[envvar].append([LID, Fld])

# By default returns first item in the list of (lid, field) pairs found.  Idx
# can be used to allow iteration through the items associated with that LID.
def getIndex(envvar, Idx=0):
   if (IndexTbl.has_key(envvar)):
	 return IndexTbl[envvar][Idx]
   return ['0', 0]

def getIndexs(envvar):
   if (IndexTbl.has_key(envvar)):
      return IndexTbl[envvar]

def setPath():
   for idx in range (len(Add2Path)):
      Add2Path[idx] = os.path.expandvars(Add2Path[idx])

   PathList=string.split(os.environ['PATH'], ':')
   PathElem={}
   ReducePath=""
   for key in PathList:
      if PathElem.has_key(key):
         PathElem[key] = PathElem[key]+1
      else:
         PathElem[key] = 1
         ReducePath=ReducePath+key+' '
   for item in Add2Path:
      if not PathElem.has_key(item):
         PathElem[item] = 1
         ReducePath=ReducePath+item+' '
   listdir = string.split(ReducePath)
   NewPath = string.join(listdir,':')
   os.environ['PATH'] = NewPath
   #return NewPath

