
#------------------------------------------------------------------------------
#
# 1. DISCLAIMER
#    THE SOFTWARE AND/OR RELATED MATERIALS ARE PROVIDED "AS-IS" WITHOUT
#    WARRANTY OF ANY KIND INCLUDING ANY WARRANTIES OF PERFORMANCE OR
#    MERCHANTABILITY OR FITNESS FOR A PARTICULAR USE OR PURPOSE (AS SET FORTH
#    IN UCC 2312-2313) OR FOR ANY PURPOSE WHATSOEVER, FOR THE LICENSED
#    PRODUCT, HOWEVER USED.
#
#    IN NO EVENT SHALL CALTECH/JPL BE LIABLE FOR ANY DAMAGES AND/OR COSTS,
#    INCLUDING BUT NOT LIMITED TO INCIDENTAL OR CONSEQUENTIAL DAMAGES OF ANY
#    KIND, INCLUDING ECONOMIC DAMAGE OR INJURY TO PROPERTY AND LOST PROFITS,
#    REGARDLESS OF WHETHER CIT/JPL SHALL BE ADVISED, HAVE REASON TO KNOW,
#    OR IN FACT SHALL KNOW OF THE POSSIBILITY.
#
#    USER BEARS ALL RISK RELATING TO QUALITY AND PERFORMANCE OF THE SOFTWARE
#    AND/OR RELATED MATERIALS.
#
# 2. The user shall comply with all applicable U.S. export control laws and
#    regulations.  To the extent that the software is subject to U.S. export
#    control laws and regulations, the user has the responsibility to obtain
#    export licenses or other export authority as may be required before
#    exporting such information to foreign countries or providing access to
#    foreign persons.
#
#------------------------------------------------------------------------------

#########################################################################
# File Name: pcf.py							#
# Directory: /home/rickf/Direct_Broadcast/bin/python/new_dev/Recovery	#
#########################################################################
import os, string, airs_utils

#########################################################################
#########################################################################
class PCF_LINE:
   def __init__(self, value):
      self.STR = value
      self.LID = 0
      self.pSize = 0
      self.PARTS = []
      self.VersionFld = 0
      self.Zone='INPUT'
      if (self.STR[0] == '#'):
         self.Comment = 1
      else:
         self.Comment = 0
      # NOTE: Comments may include a commented LID; if mentioned in an
      # input parameter file then that LID line must be uncommented.
      # Each line is assigned a LID of '0', which is changed if the line
      # has an actual LID value.  This means that a check of LID can be
      # used as a boolean.  LIDs are stored as INTEGERS, not strings!
      if (string.count(self.STR, '|') > 1):
         self.PARTS = string.split(self.STR, '|')
         self.pSize = len(self.PARTS)
         self.PARTS[0] = string.replace(self.PARTS[0], '#', '')
	 if (airs_utils.isNumeric(self.PARTS[0])):
	    self.LID = string.atoi(self.PARTS[0])
	    if (len(self.PARTS) > 3):
	       self.VersionFld = len(self.PARTS)-1
	 else:
	    self.PARTS=[] #empty list
      else:
	 self.PARTS=[] #empty list

   def getFld(self, Fld):
      if ((self.LID) and (len(self.PARTS) > Fld)):
         return self.PARTS[Fld]

   def repFld(self, Fld, Val):
      if ((self.LID) and (len(self.PARTS) > Fld)):
	 TypeVal = '%s' %(type(Val))
	 if (string.find('int', TypeVal) > 0):
            self.PARTS[Fld] = `Val`
	 else:
            self.PARTS[Fld] = Val

   def repStr(self, Str, Rep):
     if (self.PARTS == []):
        return
     if (string.count(self.STR, Str) >= 1):
	for idx in range(len(self.PARTS)):
	   if (string.count(self.PARTS[idx], Str) >= 1):
	      self.PARTS[idx] = string.replace(self.PARTS[idx], Str, Rep)
        self.STR = string.join(self.PARTS, '|')

   def getLID(self):
      return self.LID

   def getVersionField(self):
      return self.VersionFld

   def setURField(self):
      if (self.LID):
         if (self.Zone == 'INPUT'):
            if ((self.pSize >5) and (self.PARTS[4] == '')):
               self.PARTS[4] = os.path.join(self.PARTS[2], self.PARTS[1])
	       metname = '%s.%s'%(self.PARTS[1],'met')
	       FMName = os.path.join(self.PARTS[2], metname)
	       if (os.path.exists(FMName)):
	          self.PARTS[5] = metname

   def isComment(self):
      return self.Comment

   def clearComment(self):
      self.Comment = 0

   def getLine(self):
      if (self.LID):
         return string.join(self.PARTS, '|')
      else:
         return self.STR

   def setMetafileName(self):
      if not(self.Comment):
         if (len(self.PARTS) > 4):
	    FName = os.path.join(self.PARTS[2], self.PARTS[1])
	    if (os.path.exists(FName)):
	       if (self.PARTS[self.VersionFld-1] == ''):
	          MetaName = '%s.met' % (FName)
	          if (os.path.exists(MetaName)):
	             self.PARTS[self.VersionFld-1] = os.path.basename(MetaName)

   def __repr__(self):
      if (self.LID):
         RetStr =  string.join(self.PARTS, '|')
      else:
         return self.STR
      if ((self.Comment) and (len(self.PARTS) > 0)):
         RetStr = '#'+RetStr
      return RetStr

#########################################################################
def loadPCFTemplate(TemplateName, PCF_VersFld, PCF_LIDCnt):
   PCF_Template=[]
   zone='INPUT'

   PCF_List = open(TemplateName, 'r').readlines()
   for Idx in range (len(PCF_List)):
      PCF_List[Idx] = string.strip(PCF_List[Idx])
      if (len(PCF_List[Idx])):
         PCFLine = PCF_LINE(PCF_List[Idx])
         if (string.find(PCF_List[Idx], 'PRODUCT OUPUT FILES')>= 0):
            zone='OUTPUT'
         if (string.find(PCF_List[Idx], 'SUPPORT INPUT FILES')>= 0):
            zone='INPUT'
         PCFLine.Zone = zone
      PCF_Template.append(PCFLine)
      if (PCFLine.LID):
         if (not PCF_VersFld.has_key(PCFLine.LID)):
	    PCF_VersFld[PCFLine.LID] = []
	    PCF_VersFld[PCFLine.LID].append(PCFLine.getVersionField())
	 if (PCF_LIDCnt.has_key(PCFLine.LID)):
	    PCF_LIDCnt[PCFLine.LID].append(Idx)
	 else:
	    PCF_LIDCnt[PCFLine.LID] = []
	    PCF_LIDCnt[PCFLine.LID].append(Idx)


   return PCF_Template
#########################################################################
